using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;
using System.IO;


namespace rsspecan_scan_measurement_example
{
    public partial class Rsspecan_Scan_Measurement_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Scan_Measurement_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void measureAndSaveButton_Click(object sender, EventArgs e)
        {
            string instr_modl;
            double[] trace1 = new double[10000];
            double[] trace2 = new double[10000];
            double[] trace3 = new double[10000];
            double[] trace4 = new double[10000];
            double[] trace5 = new double[10000];
            double[] trace6 = new double[10000];
            double[] traceData = new double[20000];
            
            int statusReg = 0,
                traceStatus = 0, 
                noofPoints = 0,
                pointsToPrint = 0;
            StreamWriter saveFileSW = null;
            StringBuilder statusData = new StringBuilder(10000);
            int errorCode = 0;
            StringBuilder errorMessage = new StringBuilder(1024);

            try
            {
                if (SaveMeasuredDataDialog.ShowDialog() == DialogResult.OK)
                {
                    UseWaitCursor = true;
                    System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                    /* initialize driver */ 
                    if (m_instrument == null)
                        m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                    else if (ResetDevice.Checked)
                        m_instrument.reset();

                    /* check for EMI test receiver */  
                    instr_modl = m_instrument.GetString(rsspecanProperties.RsAttrInstrumentModel, "");
                    if(instr_modl.IndexOf("ESL") == -1)
                    {
                        System.Windows.Forms.Cursor.Current = Cursors.Default;
                        UseWaitCursor = false;

                        MessageBox.Show("Instrument does not support EMI scan measurements", "Error");
                        return;
                    }

                    /* switch to receiver mode */
                    m_instrument.ReceiverMode();

                    /* switch device display on/off */
                    m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                    /* set one scan at 0.1 milliseconds */
                    m_instrument.ConfigureScanTableMeasTime(1, 0.0001);

                    /* set scan step mode */
                    m_instrument.ConfigureReceiverStepMode(rsspecanConstants.SweepSpacLin);

                    /* switch to single sweep */
                    m_instrument.ConfigureAcquisition(2, false, 1);

                    /* for security reasons */
                    m_instrument.ConfigureReceiverTracePoints(10000);

                    /* Set start and stop frequency and the stepsize */
                    m_instrument.ConfigureScanTableStartStop(1, Convert.ToDouble(StartFreq.Value), Convert.ToDouble(StopFreq.Value), Convert.ToDouble(FreqStep.Value));

                    /* Send trace datas before trace is finished, too */
                    m_instrument.ConfigureReceiverTraceFeedControl(rsspecanConstants.TracFeedAlways);

                    m_instrument.ConfigureFinalReceiverDetector(1, 1, rsspecanConstants.DetectorTypeMinPeak);

                    /* Select detector */
                    if (Detector.SelectedIndex == 0) // Average
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, true, false, false, false, false, false, false);
                    }
                    else if (Detector.SelectedIndex == 1)  // Max Peak
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, false, true, false, false, false, false, false);
                    }
                    else if (Detector.SelectedIndex == 2)  // Min Peak
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, false, false, true, false, false, false, false);
                    }
                    else if (Detector.SelectedIndex == 3)  // RMS
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, false, false, false, true, false, false, false);
                    }
                    else if (Detector.SelectedIndex == 4)  // QPeak
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, false, false, false, false, true, false, false);
                    }
                    else if (Detector.SelectedIndex == 5)  // CAverage
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, false, false, false, false, false, false, true);
                    }
                    else if (Detector.SelectedIndex == 6)  // CRMS
                    {
                        m_instrument.ConfigureReceiverDetector(1, 1, false, false, false, false, false, true, false);
                    }

                    m_instrument.RunReceiverMeasurement();

                    while ((traceStatus & 0x1000) == 0)
                    {
                        //Read status register
                        m_instrument.getStatusRegister(1, out statusReg);

                        if ((statusReg & 512) != 0)
                        {
                            //Read Trace
                            m_instrument.ReadScanMeasurement(10000, out traceStatus, out noofPoints, statusData, trace1, trace2, trace3, trace4, trace5, trace6);

                            trace1.CopyTo(traceData, pointsToPrint);
                            
                            pointsToPrint += noofPoints;
                        }
                        else
                            System.Threading.Thread.Sleep(50);
                    }
                    
                    /* open save file */
                    saveFileSW = new StreamWriter(SaveMeasuredDataDialog.FileName, false, Encoding.Default);

                    /* write data to file */
                   for (int i = 0; i < pointsToPrint; i++)
                    {
                        saveFileSW.Write(traceData[i].ToString() + ";");
                    }
                }
            }
            catch (Exception ex)
            {
                String message;

                if (null != m_instrument)
                    m_instrument.error_query(out errorCode, errorMessage);

                message = "Instrument Status Error: ";
                message += errorMessage.ToString();
                message += ex.Message;
                MessageBox.Show(message);
            }
            finally
            {
                /* close file if opened */
                if (saveFileSW != null)
                {
                    saveFileSW.Close();
                }
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
                if (null != m_instrument)
                    m_instrument.Dispose();

            }
        }

        private void Rsspecan_Scan_Measurement_Example_Load(object sender, EventArgs e)
        {
            Detector.SelectedIndex = 0;
        }

    }
}