using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_phase_noise_example
{
    public partial class Rsspecan_Phase_Noise_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Phase_Noise_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double result;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* selects the spectrum analyzer mode */
                m_instrument.SetSANMode();
                
                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* switch off phase noise marker measurement (for reseting measurement) */
                m_instrument.ConfigureMarkerPhaseNoiseMeasurement(1, false);

                /* disable all markers (for reseting markers) */
                m_instrument.DisableAllMarkers(1);
                m_instrument.DisableAllDeltaMarkers(1);

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* switch on phase noise marker measurement */
                m_instrument.ConfigureMarkerPhaseNoiseMeasurement(1, true);

                /* change marker position */
                m_instrument.ConfigureDeltaMarkerPosition(1, 1, 1, Convert.ToDouble(MarkerPos.Value));

                /* read phase noise marker result */
                m_instrument.QueryPhaseNoiseResult(1, out result);

                /* show phase noise marker result in front panel */
                ResultTextBox.Text = result.ToString("E3") + " dBc/Hz";

            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}