using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_signal_count_example
{
    public partial class Rsspecan_Signal_Count_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Signal_Count_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double result;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* enable the marker */
                m_instrument.SetBoolean(rsspecanProperties.MarkerEnabled, "Win0,M1", true);

                /* enable the frequency counter */
                m_instrument.SetBoolean(rsspecanProperties.MarkerFrequencyCounterEnabled,"Win0,M1", true);

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* query counter frequency */
                m_instrument.QueryMarkerFrequencyCounterResult(1, 1, out result);


                /* show marker noise result in front panel textbox */
                ResultTextBox.Text = result.ToString("E3") + " Hz";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}