using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_limit_line_example
{
    public partial class Rsspecan_Limit_Line_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Limit_Line_Example()
        {
            InitializeComponent();
        }

        private void Rsspecan_Limit_Line_Example_Load(object sender, EventArgs e)
        {
            LimitLineType.SelectedIndex = 0;
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            int limitState;
            string[] limitResult = new string[]{"PASS","FAIL","MARGIN"}; 
            double[] limitLinePosition = new double[2];
            double[] limitLineFreq = new double[2];

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* create limit line */
                m_instrument.CreateLimitLine(1, 1, "Limit", 0, "Comment", 1, true);

                /* configure limit line */
                limitLineFreq[0] = Convert.ToDouble(StartFreq.Value);
                limitLineFreq[1] = Convert.ToDouble(StopFreq.Value);
                limitLinePosition[0] = limitLinePosition[1] = Convert.ToDouble(Position.Value);
                m_instrument.DefineLimitLine(1, LimitLineType.SelectedIndex, 2, limitLineFreq, limitLinePosition);

                /* configure limit line */
                m_instrument.ConfigureLimitLine(1, LimitLineType.SelectedIndex, 0, 0, 0, 0, Convert.ToDouble(Margin.Value), -200.0);

                /* enable limit line */
                m_instrument.EnableLimitCheck(1, 1, LimitLineType.SelectedIndex, true, true);

                /* initiate measurement */
                m_instrument.Initiate(1, timeout);

                /* queries the result of the limit check */
                m_instrument.GetLimitCheckResult(1, 1, out limitState);

                /* show limit check result */
                ResultTextBox.Text = limitResult[limitState];

            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}