using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;
using System.IO;

namespace rsspecan_hardcopy_example
{
    public partial class RSSPECAN_Hardcopy_Example : Form
    {
        private rsspecan m_instrument = null;

        public RSSPECAN_Hardcopy_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void OpenButton_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
                textBox1.Text = saveFileDialog1.FileName;
        }

        private void SaveButton_Click(object sender, EventArgs e)
        {
            string tempFilePath = "";

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* configure hardcopy options */
                m_instrument.ConfigureHardcopyDevice(1, 
                    rsspecanConstants.HcopyDestWmf, rsspecanConstants.HcopyDeviceOrientLand);

                /* select temporary file location */
                if (InstrType.SelectedIndex == 1)
                    tempFilePath = "D:\\user\\output.wmf";
                else
                    tempFilePath = "C:\\R_S\\instr\\user\\output.wmf";

                /* configure hardcopy save file */
                m_instrument.HardcopySetFileName(tempFilePath);

                /* save screen image to file */
                m_instrument.HardcopyPrint(1, rsspecanConstants.HcopAll);

                if (File.Exists(textBox1.Text) == false)
                {
                    if (saveFileDialog1.ShowDialog() == DialogResult.OK)
                        textBox1.Text = saveFileDialog1.FileName;
                    else
                        return;
                }

                /* copy file from instrument to controler */ 
                m_instrument.ReadToFileFromInstrument(tempFilePath, textBox1.Text);

                /* delete temporary file */
                m_instrument.FileManagerOperations(rsspecanConstants.FileDelete, tempFilePath, "");

            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
                m_instrument.Dispose();
                m_instrument = null;
            }
        }

        private void RSSPECAN_Hardcopy_Example_Load(object sender, EventArgs e)
        {
            InstrType.SelectedIndex = 0;
        }
    }
}