using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_wait_for_calibration_end_example
{
    public partial class Rsspecan_Wait_For_Calibration_End_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Wait_For_Calibration_End_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 50000;
            int result32;
            short result16;
            StringBuilder messageSelfTest = new StringBuilder(256);

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                if (CalEnd.Checked)
                {
                    /* Initiates the calibration and waits for its end */
                    m_instrument.Calibration(true, timeout, out result32);

                    if (result32 == 0)
                    {
                        MessageBox.Show("Calibration successful", "Calibration Result");
                    }
                    else
                    {
                        MessageBox.Show("Calibration Error code: 0x" + result32.ToString("X8"), "Calibration Result");
                    }
                }

                if (STestEnd.Checked)
                {
                    /* Initiates the self-test and waits for its end */
                    m_instrument.self_test(out result16, messageSelfTest);

                    if (result16 == 0)
                    {
                        MessageBox.Show(messageSelfTest.ToString(), "Self Test Result");
                    }
                    else
                    {
                        MessageBox.Show(messageSelfTest.ToString() + "\nSelf Test Error code: 0x" + result16.ToString("X8"), "Self Test Result");
                    }

                }

            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }

        private void CalEnd_CheckedChanged(object sender, EventArgs e)
        {
            if (CalEnd.Checked)
                STestEnd.Checked = false;
        }

        private void STestEnd_CheckedChanged(object sender, EventArgs e)
        {
            if (STestEnd.Checked)
                CalEnd.Checked = false;
        }
    }
}