using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_ndB_down_example
{
    public partial class Rsspecan_ndB_Down_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_ndB_Down_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double result;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), 0);

                /* configure sweep time */
                m_instrument.ConfigureSweepCoupling(1, 2, Convert.ToDouble(SWT.Value));

                /* switch on n dB down */
                m_instrument.ConfigureNdBPoints(1, true, Convert.ToDouble(NdBDown.Value));

                timeout = (uint)(SWT.Value * 1000) + 1000;

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* marker peak search */
                m_instrument.MarkerSearch(1, 1, 1);

                /* read n dB result */
                m_instrument.QueryNdBResult(1, out result);

                /* show n dB result in front panel textbox */
                ResultTextBox.Text = result.ToString("E3") + " s";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}