using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_statistics_CCDF_example
{
    public partial class Rsspecan_Statistics_CCDF_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Statistics_CCDF_Example()
        {
            InitializeComponent();
        }

        private void Rsspecan_Statistics_CCDF_Example_Load(object sender, EventArgs e)
        {
            Probability.SelectedIndex = 0;
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double result;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* configure parameters of signal statistic measurement */
                m_instrument.ConfigureSignalStatisticMeasurement(2, Convert.ToInt32(NumOfSamples.Value), Convert.ToDouble(ResBand.Value));

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* read out the Statistic CCDF level values */
                m_instrument.QuerySignalStatisticCCDFLevel(1, Probability.SelectedIndex, out result);

                /* show result in front panel textbox */
                ResultTextBox.Text = result + " dB";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}