using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;
using System.IO;

namespace rsspecan_read_trace_example
{
    public partial class Rsspecan_Read_Trace_example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Read_Trace_example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void MeasureAndSaveButton_Click(object sender, EventArgs e)
        {
            string instr_modl;
            double[] trace1 = new double[5000];
            int actualCount;
            StreamWriter saveFileSW = null;
            StringBuilder statusData = new StringBuilder();

            try
            {
                if (SaveMeasuredDataDialog.ShowDialog() == DialogResult.OK)
                {
                    UseWaitCursor = true;
                    System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                    /* initialize driver */
                    if (m_instrument == null)
                        m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                    else if (ResetDevice.Checked)
                        m_instrument.reset();

                    /* check for EMI test receiver */
                    instr_modl = m_instrument.GetString(rsspecanProperties.RsAttrInstrumentModel, "");
                    if (instr_modl.IndexOf("FMU") == 0 || instr_modl.IndexOf("FSC") == 0)
                    {
                        m_instrument.SetSANMode();
                    }

                    /* configure specan device: center frequency and span */
                    m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                    /* Set instrument to single sweep mode - continous mode is done
                     * programmatically because this is the only way how to
                     * synchronize measurement using *OPC
                     */
                    m_instrument.ConfigureSignalStatisticSweep(false);

                    /* Initiates a signal acquisition based on the present instrument configuration. 
                     * It then waits for the acquisition to complete, and returns the trace as an 
                     * array of amplitude values. */
                    m_instrument.ReadYTrace(1, 1, 5000, 5000, out actualCount, trace1);

                    /* open save file */
                    saveFileSW = new StreamWriter(SaveMeasuredDataDialog.FileName, false, Encoding.Default);

                    /* write data to file */
                    saveFileSW.Write("Trace data:");
                    foreach (double data in trace1)
                    {
                        saveFileSW.Write(" " + data.ToString());
                    }
                }
            }
            catch (Exception ex)
            {
                String message;

                message = "Instrument Status Error: ";
                message += ex.Message;
                MessageBox.Show(message);
            }
            finally
            {
                /* close file if opened */
                if (saveFileSW != null)
                {
                    saveFileSW.Close();
                }
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}