using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;
using System.IO;

namespace rsspecan_IQ_measurement_example
{
    public partial class Rsspecan_IQ_Measurement_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_IQ_Measurement_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void OpenButton_Click(object sender, EventArgs e)
        {
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                textBox1.Text = saveFileDialog1.FileName;
                if (File.Exists(textBox1.Text) == false)
                {
                    using (File.Create(textBox1.Text))
                    { }
                }
            }
        }

        private void SaveButton_Click(object sender, EventArgs e)
        {
            const int numberOfValues = 4096;
            uint timeout = 15000;    /* default value */
            int returnedValues;
            double[] resultI = new double[numberOfValues];
            double[] resultQ = new double[numberOfValues];

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* configure the center frequency */
                m_instrument.ConfigureFrequencyCenter(1, Convert.ToDouble(CenterFreq.Value));

                /* configure the reference level */
                m_instrument.ConfigureReferenceLevel(1, Convert.ToDouble(RefLevel.Value));

                /* select trace IQ measurement */
                m_instrument.ConfigureTraceIQDataAcquisition(1, true);

                /* configure the trace IQ */
                m_instrument.TraceIQSet(1, 32.0e6, 0, 0, 10.0e6, 0, numberOfValues);

                if (File.Exists(textBox1.Text) == false)
                {
                    if (saveFileDialog1.ShowDialog() == DialogResult.OK)
                        textBox1.Text = saveFileDialog1.FileName;
                    else
                        return;
                }

                /* This function will start a measurement and read I/Q trace data results. */
                m_instrument.ReadTraceIQData(1, timeout, numberOfValues, out returnedValues, resultI, resultQ);

                /* save data to file */
                using (StreamWriter sw = new StreamWriter(textBox1.Text))
                {
                    sw.WriteLine("Real Parts (I)\tImaginary Parts(Q)");
                    for (int i = 0; i < numberOfValues; i++)
                    {
                        sw.WriteLine("{0}\t{1}", resultI[i], resultQ[i]);
                    }
                }

                /* This function will start second measurement and read I/Q trace data results. */
                m_instrument.ReadTraceIQData(1, timeout, numberOfValues, out returnedValues, resultI, resultQ);

                /* save data to file */
                using (StreamWriter sw = File.AppendText(textBox1.Text))
                {
                    sw.WriteLine("Real Parts (I)\tImaginary Parts(Q)");
                    for (int i = 0; i < numberOfValues; i++)
                    {
                        sw.WriteLine("{0}\t{1}", resultI[i], resultQ[i]);
                    }
                }

            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}