using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_time_domain_power_measurement_example
{
    public partial class Rsspeacan_Time_Domain_Power_Measurement_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspeacan_Time_Domain_Power_Measurement_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double resultPeak, resultRMS, resultMean, resultSDev;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), 0);

                /* configure time domain power measurement parameters */
                m_instrument.ConfigureTimeDomainPowerMeasurement(1, true, true, true, true, false, false, 0);

                /* switch on time domain power measurement */
                m_instrument.ConfigureTimeDomainPowerMeasurementState(1, true);

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* query peak power result */
                m_instrument.QueryTDomPowerResult(1,0,0, out resultPeak);

                /* query RMS power result */
                m_instrument.QueryTDomPowerResult(1,1,0, out resultRMS);

                /* query mean power result */
                m_instrument.QueryTDomPowerResult(1,2,0, out resultMean);

                /* query SDEV power result */
                m_instrument.QueryTDomPowerResult(1,3,0, out resultSDev);

                /* show channel power result in front panel textbox */
                ResultTextBox.Text = "Peak\t" + resultPeak + " dBm" + Environment.NewLine +
                                     "RMS\t" + resultRMS + " dBm" + Environment.NewLine +
                                     "Mean\t" + resultMean + " dBm" + Environment.NewLine +
                                     "Standard Deviation\t" + resultSDev + " dB";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}