using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_marker_functions_example
{
    public partial class Rsspecan_Marker_Functions_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Marker_Functions_Example()
        {
            InitializeComponent();
        }

        private void ExampleForm_Load(object sender, EventArgs e)
        {
            Input.SelectedIndex = 0;
            PeakType.SelectedIndex = 0;
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000; /* default value */
            double markerPosition, markerAmplitude;
            string instrModel;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */

                m_instrument.ConfigureSignalStatisticSweep(false);

                instrModel = m_instrument.GetString(rsspecanProperties.RsAttrInstrumentModel);

                if (instrModel != "FSC" && instrModel != "FSH")
                {
                    /* select input */
                    m_instrument.ServiceConfigureInput(1, Input.SelectedIndex, Convert.ToDouble(GenAmplitude.Value));
                }

                /* Enable marker */
                m_instrument.SetBoolean(rsspecanProperties.MarkerEnabled, "Win0,M1", true);

                /* perform sweep */
                m_instrument.Initiate(1, timeout);

                /* specifies the type of marker search and performs the search */
                m_instrument.MarkerSearch(1, 1, PeakType.SelectedIndex + 1);

                /* returns the position of the selected marker */
                m_instrument.QueryMarker(1, 1, out markerPosition, out markerAmplitude);

                /* write marker position to panel */
                MarkerPosition.Text = markerPosition.ToString("E3");
                MarkerAmplitude.Text = markerAmplitude.ToString("F");

                EnableButtons(true);
            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);

                EnableButtons(false);
                PeakType.SelectedIndex = 0;
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }

        private void StopButton_Click(object sender, EventArgs e)
        {
            PeakType.SelectedIndex = 0;
            EnableButtons(false);
        }

        private void SearchButton_Click(object sender, EventArgs e)
        {
            double markerPosition, markerAmplitude;

            try
            {
                /* set peak excursion value */
                m_instrument.ConfigureMarkerSearchPeakExcursion(1, Convert.ToDouble(PeakExcursion.Value));

                /* specifies the type of marker search and performs the search */
                m_instrument.MarkerSearch(1, 1, PeakType.SelectedIndex + 1);

                /* returns the position of the selected marker */
                m_instrument.QueryMarker(1, 1, out markerPosition, out markerAmplitude);

                /* write marker position to panel */
                MarkerPosition.Text = markerPosition.ToString("E3");
                MarkerAmplitude.Text = markerAmplitude.ToString("F");
            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);

                EnableButtons(false);
                PeakType.SelectedIndex = 0;
            }
        }

        private void EnableButtons(bool enable)
        {
            PeakType.Enabled = enable;
            PeakExcursion.Enabled = enable;
            SearchButton.Enabled = enable;
            StopButton.Enabled = enable;
            StartButton.Enabled = !enable;
        }
    }
}