using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_occupied_bandwidth_example
{
    public partial class Rsspecan_Occupied_Bandwidth_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Occupied_Bandwidth_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            int returnedValues;
            double[] result = new double[1];

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* select occupied bandwidth */
                m_instrument.SelectPowerMeasurement(1, true, 3);

                /* configure occupied bandwidth parameters */
                m_instrument.ConfigureOccupiedBandwidth(1, Convert.ToDouble(PowerBand.Value), Convert.ToDouble(ChanBand.Value));

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* query power measurement results */
                m_instrument.QueryPowerResults(1, 3, 1, result, out returnedValues);

                /* show marker noise result in front panel textbox */
                ResultTextBox.Text = result[0].ToString("E3") + " Hz";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}