using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_peak_list_example
{
    public partial class Rsspecan_Peak_List_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Peak_List_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double[] peakList = new double[50];

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* configure sweep time */
                m_instrument.ConfigureSweepCoupling(1, 2, Convert.ToDouble(SWT.Value));

                /* configure peak excursion */
                m_instrument.ConfigureMarkerSearchPeakExcursion(1, Convert.ToDouble(PeakEX.Value));

                timeout = (uint)(SWT.Value * 1000) + 1000;

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* configure marker peak list */
                m_instrument.ConfigureMarkerPeakList(1, 1, (int)PeakListValues.Value, 0);

                /* read marker peak list */
                m_instrument.QueryMarkerPeakList(1, 1, (int)PeakListValues.Value, 0, peakList);



                PeakListTable.Rows.Clear();

                /* write peak list to table */
                for (int i = 0; i < PeakListValues.Value; i++)
                {
                    PeakListTable.Rows.Add();
                    PeakListTable.Rows[i].Cells["Frequency"].Value = peakList[i];
                }


                /* read marker peak list */
                m_instrument.QueryMarkerPeakList(1, 1, (int)PeakListValues.Value, 1, peakList);

                /* write peak list to table */
                for (int i = 0; i < PeakListValues.Value; i++)
                {
                    PeakListTable.Rows[i].Cells["Amplitude"].Value = peakList[i];
                }
            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}