using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_multi_carrier_ACP_measurement_example
{
    public partial class Rsspecan_Multi_Carrier_ACP_Measurement_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Multi_Carrier_ACP_Measurement_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            int returnedValues;
            double[] result = new double[9];

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* configure adjacent power measurement */
                m_instrument.SelectPowerMeasurement(1, true, 2);

                /* configure adjacent power measurement */
                m_instrument.ConfigureMulticarrierACPPower(1, 2, 4, 1, 0, false);
				
                /* adjust power measurement */
                m_instrument.ACPChannelPowerAutoAdjust(1, 15000);

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* query channel power */
                m_instrument.QueryPowerResults(1, 2, 9, result, out returnedValues);

                /* show channel power result in front panel textbox */
                ResultTextBox.Text = "Power of carrier signal 1 \t" + result[0] + " dBm" + Environment.NewLine +
                                     "Power of carrier signal 2 \t" + result[1] + " dBm" + Environment.NewLine +
                                     "Power of carrier signal 3 \t" + result[2] + " dBm" + Environment.NewLine +
                                     "Power of carrier signal 4 \t" + result[3] + " dBm" + Environment.NewLine +
                                     "Total power of all carrier signals \t" + result[4] + " dBm" + Environment.NewLine +
                                     "Power of lower adjacent channel \t" + result[5] + " dB" + Environment.NewLine +
                                     "Power of upper adjacent channel \t" + result[6] + " dB" + Environment.NewLine +
                                     "Power of lower alternate channel 1 \t" + result[7] + " dB" + Environment.NewLine +
                                     "Power of upper alternate channel 1 \t" + result[8] + " dB";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}