using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_reference_fixed_example
{
    public partial class Rsspecan_Reference_Fixed_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Reference_Fixed_Example()
        {
            InitializeComponent();
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            uint timeout = 15000;    /* default value */
            double position, amplitude;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* do a sweep */
                m_instrument.Initiate(1, timeout);

                /* set marker to peak */
                m_instrument.MarkerSearch(1, 1, 1);
                //m_instrument.DeltaMarkerSearch(1, 1, 1);

                /* activate ref fixed */
                m_instrument.ConfigureReferenceFixed(1, true);

                /* search for delta marker */
                m_instrument.QueryDeltaMarker(1, 1, 1, out position, out amplitude);

                /* show marker noise result in front panel textbox */
                ResultPosition.Text = position.ToString("E3") + " Hz";
                ResultLevel.Text = amplitude.ToString("F") + " dB";


            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}