using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rsspecan_spurious_emissions_example
{
    public partial class Rsspecan_Spurious_Emissions_Example : Form
    {
        private rsspecan m_instrument = null;

        public Rsspecan_Spurious_Emissions_Example()
        {
            InitializeComponent();
        }

        private void Rsspecan_Spurious_Emissions_Example_Load(object sender, EventArgs e)
        {
            Detector.SelectedIndex = 4;
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void StartButton_Click(object sender, EventArgs e)
        {
            int returnedValues;
            double[] frequency = new double[50];
            double[] level = new double[50];
            double[] deltaLimit = new double[50];

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;

                /* initialize driver */
                if (m_instrument == null)
                    m_instrument = new rsspecan(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);
                else if (ResetDevice.Checked)
                    m_instrument.reset();

                /* switch device display on/off */
                m_instrument.ConfigureDisplayUpdate(DisplayEnable.Checked);

                /* Set instrument to single sweep mode - continous mode is done
                 * programmatically because this is the only way how to
                 * synchronize measurement using *OPC
                 */
                m_instrument.ConfigureSignalStatisticSweep(false);

                /* configure specan device: center frequency and span */
                m_instrument.ConfigureFrequencyCenterSpan(1, Convert.ToDouble(CenterFreq.Value), Convert.ToDouble(Span.Value));

                /* switch on the spurious emissions measurement */
                m_instrument.ConfigureSEState(true);

                /* configure the peak search for spurious emission measurement */
                m_instrument.ConfigureSEPeakSearch(1, Convert.ToDouble(Margin.Value), Convert.ToInt32(PeakNum.Value));

                /* configure the start and stop frequency for the specified range */
                m_instrument.ConfigureSESweepListStartStop(1, Convert.ToDouble(StartFreq.Value), Convert.ToDouble(StopFreq.Value));

                /* configure the resolution and video bandwidth values for the specified range */
                m_instrument.ConfigureSESweepListBandwidth(1, Convert.ToDouble(ResBand.Value), Convert.ToDouble(VidBand.Value));

                /* configure the detector value for the specified range */
                m_instrument.ConfigureSESweepListDetector(1, Detector.SelectedIndex);

                /* configure the reference level for the specified range */
                m_instrument.ConfigureSESweepListReferenceLevel(1,Convert.ToDouble(RefLevel.Value));

                /* start a new spurious measurement */
                m_instrument.InitiateSpurious(1, Convert.ToUInt32(Timeout.Value));

                /* search the peaks in spurious emissions data */
                m_instrument.SESearchPeak();

                /* read the spurious emissions peak list */
                m_instrument.ReadSEPeakList(Convert.ToInt32(PeakNum.Value), frequency, level, deltaLimit, out returnedValues);

                PeakListTable.Rows.Clear();

                /* write peak list to table */
                for (int i = 0; i < PeakNum.Value; i++)
                {
                    PeakListTable.Rows.Add();
                    PeakListTable.Rows[i].Cells["Frequency"].Value = frequency[i];
                    PeakListTable.Rows[i].Cells["Level"].Value = level[i];
                    PeakListTable.Rows[i].Cells["DeltaLimit"].Value = deltaLimit[i];
                }
            }
            catch (System.Runtime.InteropServices.ExternalException ex)
            {
                String message;

                message = "Instrument Status Error: " + ex.Message + Environment.NewLine;
                message += "Instrument Error Code: " + ex.ErrorCode.ToString("X");
                MessageBox.Show(message);
            }
            finally
            {
                System.Windows.Forms.Cursor.Current = Cursors.Default;
                UseWaitCursor = false;
            }
        }
    }
}